# GIFT/DAVT Project Documentation

- Point of contact: [John Bowyer](mailto:jcbowyer@hotmail.com)
- Organizational unit: Pending Public Release
- Related projects: Pending Public Release
- Related investments:  Pending Public Release
- Governance status: Pending Public Release
- Program official:  Pending Public Release


